@@ -3,12 +3,11 @@ import platform
 from typing import Final
 
 import aiohttp
-import homeassistant.core
 
 LOG: Final = logging.getLogger(__package__)
 DEFAULT_STATE_FILE: Final = "hilo_state.yaml"
 REQUEST_RETRY: Final = 9
-PYHILO_VERSION: Final = "2024.10.02"
+PYHILO_VERSION: Final = "2025.4.01"
 # TODO: Find a way to keep previous line in sync with pyproject.toml automatically
 
 CONTENT_TYPE_FORM: Final = "application/x-www-form-urlencoded"
@@ -42,9 +41,11 @@ API_REGISTRATION_HEADERS: Final = {
 
 # Automation server constant
 AUTOMATION_DEVICEHUB_ENDPOINT: Final = "/DeviceHub"
+AUTOMATION_CHALLENGE_ENDPOINT: Final = "/ChallengeHub"
+
 
 # Request constants
-DEFAULT_USER_AGENT: Final = f"PyHilo/{PYHILO_VERSION} HomeAssistant/{homeassistant.core.__version__} aiohttp/{aiohttp.__version__} Python/{platform.python_version()}"
+DEFAULT_USER_AGENT: Final = f"PyHilo/{PYHILO_VERSION} aiohttp/{aiohttp.__version__} Python/{platform.python_version()}"
 
 
 # NOTE(dvd): Not sure how to get new ones so I'm using the ones from my emulator
@@ -194,7 +195,7 @@ HILO_DEVICE_TYPES: Final = {
 }
 
 HILO_UNIT_CONVERSION: Final = {
-    "Celcius": "°C",
+    "Celsius": "°C",
     "DB": "dB",
     "Integer": "dB",
     "Mbar": "mbar",
@@ -207,7 +208,7 @@ HILO_READING_TYPES: Final = {
     "BatteryPercent": "Percentage",
     "Co2": "PPM",
     "ColorTemperature": "Integer",
-    "CurrentTemperature": "Celcius",
+    "CurrentTemperature": "Celsius",
     "Disconnected": "null",
     "DrmsState": "OnOff",
     "firmwareVersion": "null",
@@ -215,8 +216,8 @@ HILO_READING_TYPES: Final = {
     "Hue": "Integer",
     "Humidity": "Percentage",
     "Intensity": "Percentage",
-    "MaxTempSetpoint": "Celcius",
-    "MinTempSetpoint": "Celcius",
+    "MaxTempSetpoint": "Celsius",
+    "MinTempSetpoint": "Celsius",
     "Noise": "DB",
     "onlineStatus": "null",
     "OnOff": "OnOff",
@@ -224,7 +225,7 @@ HILO_READING_TYPES: Final = {
     "Pressure": "Mbar",
     "Saturation": "Integer",
     "Status": "OnOff",
-    "TargetTemperature": "Celcius",
+    "TargetTemperature": "Celsius",
     "Unpaired": "null",
     "WifiStatus": "Integer",
     "zigBeePairingActivated": "OnOff",
@@ -267,3 +268,5 @@ UNMONITORED_DEVICES: Final = [
     "43094",
     "43100",
 ]
+
+STATE_UNKNOWN: Final = "unknown"
